.. _Postman: https://documenter.getpostman.com/view/8887939/TVmS9GDG
.. _api:

API Reference
=============
This reference applies to the API exposed through the Python client,
:ref:`synthpy <getting_started>`. Under the hood, it consumes
:ref:`synthd <synthd>`'s `REST` API. You can find a full documentation
of the available endpoints and core conventions of that API on `Postman`_.

.. toctree::
   :maxdepth: 2

   client
   model
   ingest
   generate
   namespace
   override
